==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/customerrental_001/ReturnDetails.java <==

package net.datastream.schemas.mp_entities.customerrental_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RETURNDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDRETURNDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RETURNREADING" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RETURNUOM" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RETURNLOCATION" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RETURNFUELLEVEL" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RETURNEDTO" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "returndate",
    "estimatedreturndate",
    "returnreading",
    "returnuom",
    "returnlocation",
    "returnfuellevel",
    "returnedto"
})
@XmlRootElement(name = "ReturnDetails")
public class ReturnDetails {

    @XmlElement(name = "RETURNDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME returndate;
    @XmlElement(name = "ESTIMATEDRETURNDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME estimatedreturndate;
    @XmlElement(name = "RETURNREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY returnreading;
    @XmlElement(name = "RETURNUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String returnuom;
    @XmlElement(name = "RETURNLOCATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type returnlocation;
    @XmlElement(name = "RETURNFUELLEVEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY returnfuellevel;
    @XmlElement(name = "RETURNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type returnedto;

    /**
     * Gets the value of the returndate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getRETURNDATE() {
        return returndate;
    }

    /**
     * Sets the value of the returndate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setRETURNDATE(DATETIME value) {
        this.returndate = value;
    }

    /**
     * Gets the value of the estimatedreturndate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getESTIMATEDRETURNDATE() {
        return estimatedreturndate;
    }

    /**
     * Sets the value of the estimatedreturndate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setESTIMATEDRETURNDATE(DATETIME value) {
        this.estimatedreturndate = value;
    }

    /**
     * Gets the value of the returnreading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRETURNREADING() {
        return returnreading;
    }

    /**
     * Sets the value of the returnreading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRETURNREADING(QUANTITY value) {
        this.returnreading = value;
    }

    /**
     * Gets the value of the returnuom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRETURNUOM() {
        return returnuom;
    }

    /**
     * Sets the value of the returnuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRETURNUOM(String value) {
        this.returnuom = value;
    }

    /**
     * Gets the value of the returnlocation property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getRETURNLOCATION() {
        return returnlocation;
    }

    /**
     * Sets the value of the returnlocation property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setRETURNLOCATION(LOCATIONID_Type value) {
        this.returnlocation = value;
    }

    /**
     * Gets the value of the returnfuellevel property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRETURNFUELLEVEL() {
        return returnfuellevel;
    }

    /**
     * Sets the value of the returnfuellevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRETURNFUELLEVEL(QUANTITY value) {
        this.returnfuellevel = value;
    }

    /**
     * Gets the value of the returnedto property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getRETURNEDTO() {
        return returnedto;
    }

    /**
     * Sets the value of the returnedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setRETURNEDTO(USERID_Type value) {
        this.returnedto = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/customerrental_001/ReturnDetails.java <==

package net.datastream.schemas.mp_entities.customerrental_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDRETURNDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNLOCATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNFUELLEVEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNEDTO" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "returndate",
    "estimatedreturndate",
    "returnreading",
    "returnuom",
    "returnlocation",
    "returnfuellevel",
    "returnedto"
})
@XmlRootElement(name = "ReturnDetails")
public class ReturnDetails {

    @XmlElement(name = "RETURNDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME returndate;
    @XmlElement(name = "ESTIMATEDRETURNDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME estimatedreturndate;
    @XmlElement(name = "RETURNREADING", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY returnreading;
    @XmlElement(name = "RETURNUOM", namespace = "http://schemas.datastream.net/MP_fields")
    protected String returnuom;
    @XmlElement(name = "RETURNLOCATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type returnlocation;
    @XmlElement(name = "RETURNFUELLEVEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY returnfuellevel;
    @XmlElement(name = "RETURNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type returnedto;

    /**
     * Gets the value of the returndate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getRETURNDATE() {
        return returndate;
    }

    /**
     * Sets the value of the returndate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setRETURNDATE(DATETIME value) {
        this.returndate = value;
    }

    /**
     * Gets the value of the estimatedreturndate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getESTIMATEDRETURNDATE() {
        return estimatedreturndate;
    }

    /**
     * Sets the value of the estimatedreturndate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setESTIMATEDRETURNDATE(DATETIME value) {
        this.estimatedreturndate = value;
    }

    /**
     * Gets the value of the returnreading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRETURNREADING() {
        return returnreading;
    }

    /**
     * Sets the value of the returnreading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRETURNREADING(QUANTITY value) {
        this.returnreading = value;
    }

    /**
     * Gets the value of the returnuom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRETURNUOM() {
        return returnuom;
    }

    /**
     * Sets the value of the returnuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRETURNUOM(String value) {
        this.returnuom = value;
    }

    /**
     * Gets the value of the returnlocation property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getRETURNLOCATION() {
        return returnlocation;
    }

    /**
     * Sets the value of the returnlocation property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setRETURNLOCATION(LOCATIONID_Type value) {
        this.returnlocation = value;
    }

    /**
     * Gets the value of the returnfuellevel property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRETURNFUELLEVEL() {
        return returnfuellevel;
    }

    /**
     * Sets the value of the returnfuellevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRETURNFUELLEVEL(QUANTITY value) {
        this.returnfuellevel = value;
    }

    /**
     * Gets the value of the returnedto property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getRETURNEDTO() {
        return returnedto;
    }

    /**
     * Sets the value of the returnedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setRETURNEDTO(USERID_Type value) {
        this.returnedto = value;
    }

}
